.. _developer_documentation:

=======================
Developer documentation
=======================

In this section, you will find documentation relevant to developing
Designate.

Contents:

.. toctree::
   :maxdepth: 2

   getting-involved
   Designate Tempest Plugin <https://docs.openstack.org/designate-tempest-plugin/latest>
   architecture
   gmr
   sourcedoc/index
   ubuntu-dev
   integrations

Other modules
~~~~~~~~~~~~~

.. toctree::
    :maxdepth: 1

    python-designateclient <https://docs.openstack.org/python-designateclient/latest/>
    designate-dashboard <https://docs.openstack.org/designate-dashboard/latest/>
    designate-tempest-plugin <https://docs.openstack.org/designate-tempest-plugin/>
    designate-specs <https://specs.openstack.org/openstack/designate-specs/>
